@@ -37,7 +37,7 @@ class Data_inegrator:
 
         # train and validate only according to the patients with both fields.
 
-        train_size = int(parse_args.train_size * self.xy_dataset)
+        train_size = int(parse_args.train_size * len(self.xy_dataset))
         validation_size = len(self.xy_dataset) - train_size
 
         # split the data into train and validation
